==> openGion8.4.3.0_src.zip: uap/webapps/gf/jsp/common/default.js <==
var $jscomp=$jscomp||{};$jscomp.scope={};$jscomp.findInternal=function(a,b,c){a instanceof String&&(a=String(a));for(var d=a.length,e=0;e<d;e++){var f=a[e];if(b.call(c,f,e,a))return{i:e,v:f}}return{i:-1,v:void 0}};$jscomp.ASSUME_ES5=!1;$jscomp.ASSUME_NO_NATIVE_MAP=!1;$jscomp.ASSUME_NO_NATIVE_SET=!1;$jscomp.SIMPLE_FROUND_POLYFILL=!1;$jscomp.ISOLATE_POLYFILLS=!1;$jscomp.FORCE_POLYFILL_PROMISE=!1;$jscomp.FORCE_POLYFILL_PROMISE_WHEN_NO_UNHANDLED_REJECTION=!1;
$jscomp.defineProperty=$jscomp.ASSUME_ES5||"function"==typeof Object.defineProperties?Object.defineProperty:function(a,b,c){if(a==Array.prototype||a==Object.prototype)return a;a[b]=c.value;return a};$jscomp.getGlobal=function(a){a=["object"==typeof globalThis&&globalThis,a,"object"==typeof window&&window,"object"==typeof self&&self,"object"==typeof global&&global];for(var b=0;b<a.length;++b){var c=a[b];if(c&&c.Math==Math)return c}throw Error("Cannot find global object");};$jscomp.global=$jscomp.getGlobal(this);
$jscomp.IS_SYMBOL_NATIVE="function"===typeof Symbol&&"symbol"===typeof Symbol("x");$jscomp.TRUST_ES6_POLYFILLS=!$jscomp.ISOLATE_POLYFILLS||$jscomp.IS_SYMBOL_NATIVE;$jscomp.polyfills={};$jscomp.propertyToPolyfillSymbol={};$jscomp.POLYFILL_PREFIX="$jscp$";var $jscomp$lookupPolyfilledValue=function(a,b){var c=$jscomp.propertyToPolyfillSymbol[b];if(null==c)return a[b];c=a[c];return void 0!==c?c:a[b]};
$jscomp.polyfill=function(a,b,c,d){b&&($jscomp.ISOLATE_POLYFILLS?$jscomp.polyfillIsolated(a,b,c,d):$jscomp.polyfillUnisolated(a,b,c,d))};$jscomp.polyfillUnisolated=function(a,b,c,d){c=$jscomp.global;a=a.split(".");for(d=0;d<a.length-1;d++){var e=a[d];if(!(e in c))return;c=c[e]}a=a[a.length-1];d=c[a];b=b(d);b!=d&&null!=b&&$jscomp.defineProperty(c,a,{configurable:!0,writable:!0,value:b})};
$jscomp.polyfillIsolated=function(a,b,c,d){var e=a.split(".");a=1===e.length;d=e[0];d=!a&&d in $jscomp.polyfills?$jscomp.polyfills:$jscomp.global;for(var f=0;f<e.length-1;f++){var g=e[f];if(!(g in d))return;d=d[g]}e=e[e.length-1];c=$jscomp.IS_SYMBOL_NATIVE&&"es6"===c?d[e]:null;b=b(c);null!=b&&(a?$jscomp.defineProperty($jscomp.polyfills,e,{configurable:!0,writable:!0,value:b}):b!==c&&(void 0===$jscomp.propertyToPolyfillSymbol[e]&&(c=1E9*Math.random()>>>0,$jscomp.propertyToPolyfillSymbol[e]=$jscomp.IS_SYMBOL_NATIVE?
$jscomp.global.Symbol(e):$jscomp.POLYFILL_PREFIX+c+"$"+e),$jscomp.defineProperty(d,$jscomp.propertyToPolyfillSymbol[e],{configurable:!0,writable:!0,value:b})))};$jscomp.polyfill("Array.prototype.find",function(a){return a?a:function(b,c){return $jscomp.findInternal(this,b,c).v}},"es6","es3");
function getInternetExplorerVersion(){var a=-1;if("Microsoft Internet Explorer"==navigator.appName){var b=navigator.userAgent;var c=/MSIE ([0-9]{1,}[.0-9]{0,})/;null!=c.exec(b)&&(a=parseFloat(RegExp.$1))}return a}var isCSS,isW3C,isIE4,isNN4,isIE6CSS;
function initDHTMLAPI(){document.images&&(isW3C=(isCSS=document.body&&document.body.style?!0:!1)&&document.getElementById?!0:!1,isIE4=isCSS&&document.all?!0:!1,isNN4=document.layers?!0:!1,isIE6CSS=document.compatMode&&0<=document.compatMode.indexOf("CSS1")?!0:!1);__bInitDhtmlApi=!0}var __bInitDhtmlApi=!1;function getInsideWindowWidth(){return window.innerWidth?window.innerWidth:isIE6CSS?document.body.parentElement.clientWidth:document.body&&document.body.clientWidth?document.body.clientWidth:0}
function getInsideWindowHeight(){return window.innerHeight?window.innerHeight:isIE6CSS?document.body.parentElement.clientHeight:document.body&&document.body.clientHeight?document.body.clientHeight:0}function addEvent(a,b,c,d){if(a.addEventListener)return a.addEventListener(b,c,d?!0:!1),!0;if(a.attachEvent)return a.attachEvent("on"+b,c);a["on"+b]=c}var _sCompat_=document.compatMode,bIsCSS1Compat="CSS1Compat"==_sCompat_;
function focus2(){var a,b,c,d;var e=document.getElementsByName("h_fcs");if(0<e.length){e=e[0];for(c=e.parentNode;c;){"TR"==c.tagName&&(a=c);if(a&&"DIV"==c.tagName&&("layer"==c.id&&(b=c),"X1"==c.id||"X2"==c.id)){var f=c;f.HSibling||(f.HSibling=document.getElementById("X1"==c.id?"X2":"X1"));break}c=c.parentNode}var g=(c=b?b.getElementsByTagName("THEAD"):null)&&0<c.length?c[0].offsetHeight+5:0;b?(0<c.length&&"divheader"==c[0].id&&(d=c[0]),d?(e.scrollIntoView(!0),b.scrollTop>=d.offsetHeight&&(b.scrollTop-=
d.offsetHeight)):(b.scrollIntoView(!0),b.scrollTop=Math.max(a.offsetTop-g,0),b.HSibling&&(b.HSibling.scrollTop=Math.max(a.offsetTop-g,0)))):f?(f.scrollIntoView(!0),f.scrollTop=Math.max(a.offsetTop-g,0),f.HSibling&&(f.HSibling.scrollTop=Math.max(a.offsetTop-g,0))):a?window.scrollTo(0,a.offsetTop):e.scrollIntoView(!0)}}
function historyBack(){var a;var b=document.getElementsByTagName("FORM");if(0<b.length)for(b=b[0],a=0;a<b.elements.length;a++){var c=b.elements[a];if(null!=c&&"historyBack"==c.name){"1"==c.value?(c.value="0",b.submit()):c.value="1";break}}}function changeImage(a,b){document.images[a].src=b}var isClicked=!1;function oneClick(){return isClicked?(alert("Don't click twice."),!1):isClicked=!0}
function renew(a,b,c){var d=null;null!=c?d=c.form:(c=document.getElementsByTagName("FORM"),0<c.length&&(d=c[0]));null!=d&&(d.action=a,d.target=b,d.submit())}function nextForm(a,b,c){a.value.length>=c&&(a=a.form.elements[b],null!=a[0]&&null!=a[0].name?a[0].focus():null!=a?a.focus():alert("There is no field named ["+b+"]"))}function checkbox(a){var b;var c=a.form;if(null!=c){c=c.elements;var d=c.length;for(b=0;b<d;b++){var e=c[b];if("h_rowSel"==e.name||"ALL_CHECK"==e.name)e.checked=a.checked}}}
var EMPTY_STR="",strOldKey=EMPTY_STR,oOldSelect=null,BACKSPACE_CODE=8;function clearOldKey(){strOldKey=EMPTY_STR}
function setKeySelect(a){var b;var c=!1;oOldSelect!=a&&(strOldKey=EMPTY_STR,oOldSelect=a,null==a.onblur&&(a.onblur=clearOldKey));var d=a.options;var e=event.keyCode;if(37<=e&&40>=e||48<=e&&90>=e||96<=e&&105>=e||BACKSPACE_CODE==e)if(b=37<=e&&40>=e&&!event.shiftKey)strOldKey=EMPTY_STR;else{b=90>=e?String.fromCharCode(e).toUpperCase():String.fromCharCode(e-48);e=BACKSPACE_CODE==e?0<strOldKey.length?strOldKey.substr(0,strOldKey.length-1):EMPTY_STR:strOldKey+b;var f=e.length;for(b=0;b<d.length;b++)if(e==
d(b).text.substr(0,f).toUpperCase()||e==d(b).value.substr(0,f).toUpperCase()){c=!0;break}c&&(strOldKey=e,a.selectedIndex!=b&&(a.selectedIndex=b));event.returnValue=!1}return c}function window_open(a,b,c,d){null!=b&&(b="left="+b.x+",top="+b.y,null!=d&&(d+=","+b));window.open(a,c,d)}
function adjustFrameHeight(a){var b;if(a){var c=Math.round(1E3/a)/10+"%";$("body").css({zoom:a,width:c,height:c})}else a=1;adjustFrameHeight_iframe();var d=parent.document.getElementsByName("SUB_FRAME");if(null!=d){var e=c=null;1==d.length&&(c=d[0],e=parent.frames);if(null!=c&&null!=c.rows&&0!=c.rows.length&&null!=e&&0!=e.length){var f=c.rows.split(",");d=null;var g=Math.min(f.length,e.length);for(b=0;b<g-1;b++)if(f=e[b].document.getElementById("END_MARKER"),null==f)d=d+e[b].document.body.clientHeight+
",";else{var h=e[b].document.documentElement.scrollWidth;var l=e[b].document.documentElement.clientWidth;var m="a"==/a/[-1];var k=5;if(m||h!=l)k+=14;d=d+Math.ceil((f.offsetTop+f.parentNode.offsetTop)*a)+k+","}c.rows=d+"*"}}}
function adjustFrameWidth(){var a;var b=parent.document.getElementsByName("RES_FRAME");if(null!=b){var c=a=null;1==b.length&&(a=b[0],c=parent.frames);if(null!=a&&null!=a.cols&&0!=a.cols.length&&null!=c&&0!=c.length)for(b=0;b<c.length;b++)if("UPDATE"==c[b].name){sw=c[b].document.documentElement.scrollWidth;c=sw+2;a.cols="*,"+c;break}}}var initRow={};
function autoArea(a,b){var c;if(null!=a&&(null==initRow[a.name]&&(initRow[a.name]=a.rows),isCntAction(event.keyCode))){var d=a.value;var e=1;for(c=d.indexOf("\n");0<=c;)e++,c=d.indexOf("\n",c+1);e<initRow[a.name]&&(e=initRow[a.name]);null!=b&&e>b&&(e=b);a.rows=e}}function isCntAction(a){return 13==a||14==a||8==a||46==a||67==a||86==a||88==a}
function hide(a,b){var c=document.getElementById(a+"A");if(null!=c){var d=document.getElementById(a+"B");a=null;null!=b&&(a=document.getElementsByName(b));if("none"==c.style.display){if(c.style.display="inline",null!=d&&(d.innerHTML="- "),null!=a)for(b=1;b<a.length;b++)a[b].value="false"}else if(c.style.display="none",null!=d&&(d.innerHTML="+ "),null!=a)for(b=1;b<a.length;b++)a[b].value="true"}adjustFrameHeight()}
function replaceText(a,b,c){if(null!=a)for(;0<=a.indexOf(b);)a=a.replace(b,c);return a}function getDimensions(a){var b,c;var d=a.offsetWidth;var e=a.offsetHeight;for(c=b=0;null!=a;a=a.offsetParent)b+=a.offsetTop,c+=a.offsetLeft;return{top:b,left:c,width:d,height:e}}function getClientHeight(){return bIsCSS1Compat?document.documentElement.clientHeight:document.body.clientHeight}function getClientWidth(){return bIsCSS1Compat?document.documentElement.clientWidth:document.body.clientWidth}
function hilightRow(){}function submitPrevNextForm(a){var b=document.forms[0];var c=document.getElementById("h_cmd");null!=b&&null!=c&&(c.value=a,b.submit(),c.value="NEW");return!1}function hideClass(a,b,c,d,e){atsrc=$(b).attr("src");0<=atsrc.indexOf(d)?$(b).attr("src",atsrc.replace(d,e)):$(b).attr("src",atsrc.replace(e,d));$("."+c).toggle();adjustFrameHeight()}var ogEvents={};
function setEvent(a,b,c,d,e,f){null==ogEvents[a]&&(ogEvents[a]=[]);ogEvents[a][ogEvents[a].length]={event:b,"function":c,filter:d,fire:e,bindFunc:f}}var endInitEvent=!1;function bindEvents(a){var b,c,d;for(b in ogEvents){var e=a?a.find(b):$(b);var f=ogEvents[b];for(c=0;c<f.length;c++){f[c].bindFunc&&f[c].bindFunc();var g=f[c].filter?e.filter(f[c].filter):e;g.on(f[c].event,f[c]["function"]);if(f[c].fire)for(d=0;d<g.length;d++)$(g[d]).triggerHandler(f[c].event)}}endInitEvent=!0}
function isEndInitEvent(){return endInitEvent}function selChanged(a){var b=a.textObj;b.value=a.options[a.selectedIndex].value;""==b.value&&(b.value=a.options[a.selectedIndex].text);$(b).trigger("change")}
function makeInputMenu(a,b){var c=document.getElementById(a);var d=document.getElementById(a+".sel");void 0==b?b=0:b++;if((!c.setSel||0==c.offsetWidth)&&10>b)c.setSel=!0,setTimeout("makeInputMenu('"+a+"',"+b+")",200);else{a=c.offsetWidth-18+"px";d.style.position="absolute";d.style.width=c.offsetWidth+"px";d.style.height=c.offsetHeight+"px";b=getDimensions(c);var e=getDimensions(d.offsetParent);d.style.left=b.left-e.left+"px";d.style.top=b.top-e.top+"px";d.style.clip="rect(auto auto auto "+a+")";d.textObj=
c;d.selectedIndex=-1}}function ogOpen(a,b,c,d){null!=b&&(b="left="+b.x+",top="+b.y,null!=d&&(d+=","+b));window.open(a,c,d)}function setDisplayCapture(a){clipboardData.setData("Text",a);setTimeout("getDisplayCapture()",1E3)}function getDisplayCapture(){var a=clipboardData.getData("Text");0==a.lastIndexOf("ERROR:",0)&&alert(a);return a}
function adjustFrameHeight_iframe(){var a=$("iframe.HYBS_IFRAME",parent.document);if(!(1>a.length)){var b=0,c=document.documentElement.scrollWidth,d=document.documentElement.clientWidth,e="a"==/a/[-1];$(a).each(function(f,g){if(f!=a.length-1){f=$("#END_MARKER",$(g).contents())[0];var h=5;if(e||c!=d)h+=14;f=f.offsetTop+f.parentNode.offsetTop+h;$(g).height(f);b=b+f+8}else $(g).css("height","calc(100% - "+b+"px)").css("min-height","100px")})}}
function dateFormat(a,b){b=b.replace(/yyyy/,a.getFullYear());b=b.replace(/MM/,("0"+(a.getMonth()+1)).slice(-2));b=b.replace(/dd/,("0"+a.getDate()).slice(-2));b=b.replace(/HH/,("0"+a.getHours()).slice(-2));b=b.replace(/mm/,("0"+a.getMinutes()).slice(-2));return b=b.replace(/ss/,("0"+a.getSeconds()).slice(-2))}
function toZenkakuKana(a){for(var b="\uff67 \uff68 \uff69 \uff6a \uff6b \uff6c \uff6d \uff6e \uff6f \uff70 \uff73\uff9e \uff76\uff9e \uff77\uff9e \uff78\uff9e \uff79\uff9e \uff7a\uff9e \uff7b\uff9e \uff7c\uff9e \uff7d\uff9e \uff7e\uff9e \uff7f\uff9e \uff80\uff9e \uff81\uff9e \uff82\uff9e \uff83\uff9e \uff84\uff9e \uff8a\uff9e \uff8b\uff9e \uff8c\uff9e \uff8d\uff9e \uff8e\uff9e \uff8a\uff9f \uff8b\uff9f \uff8c\uff9f \uff8d\uff9f \uff8e\uff9f \uff71 \uff72 \uff73 \uff74 \uff75 \uff76 \uff77 \uff78 \uff79 \uff7a \uff7b \uff7c \uff7d \uff7e \uff7f \uff80 \uff81 \uff82 \uff83 \uff84 \uff85 \uff86 \uff87 \uff88 \uff89 \uff8a \uff8b \uff8c \uff8d \uff8e \uff8f \uff90 \uff91 \uff92 \uff93 \uff94 \uff95 \uff96 \uff97 \uff98 \uff99 \uff9a \uff9b \uff9c \uff66 \uff9d".split(" "),c=
"\u30a1\u30a3\u30a5\u30a7\u30a9\u30e3\u30e5\u30e7\u30c3\u30fc\u30f4\u30ac\u30ae\u30b0\u30b2\u30b4\u30b6\u30b8\u30ba\u30bc\u30be\u30c0\u30c2\u30c5\u30c7\u30c9\u30d0\u30d3\u30d6\u30d9\u30dc\u30d1\u30d4\u30d7\u30da\u30dd\u30a2\u30a4\u30a6\u30a8\u30aa\u30ab\u30ad\u30af\u30b1\u30b3\u30b5\u30b7\u30b9\u30bb\u30bd\u30bf\u30c1\u30c4\u30c6\u30c8\u30ca\u30cb\u30cc\u30cd\u30ce\u30cf\u30d2\u30d5\u30d8\u30db\u30de\u30df\u30e0\u30e1\u30e2\u30e4\u30e6\u30e8\u30e9\u30ea\u30eb\u30ec\u30ed\u30ef\u30f2\u30f3".split(""),
d=0;d<b.length;d++)a=a.replace(new RegExp(b[d],"g"),c[d]);return a}var ajaxCall=function(a){$.ajax({url:a,async:!1,type:"GET",dataType:"html"})};

==> openGion8.5.2.0_src.zip: uap/webapps/gf/jsp/common/default.js <==
function getInternetExplorerVersion(){var a=-1;if("Microsoft Internet Explorer"==navigator.appName){var b=navigator.userAgent;var c=RegExp("MSIE ([0-9]{1,}[.0-9]{0,})");null!=c.exec(b)&&(a=parseFloat(RegExp.$1))}return a}var isCSS,isW3C,isIE4,isNN4,isIE6CSS;
function initDHTMLAPI(){document.images&&(isW3C=(isCSS=document.body&&document.body.style?!0:!1)&&document.getElementById?!0:!1,isIE4=isCSS&&document.all?!0:!1,isNN4=document.layers?!0:!1,isIE6CSS=document.compatMode&&0<=document.compatMode.indexOf("CSS1")?!0:!1);__bInitDhtmlApi=!0}var __bInitDhtmlApi=!1;function getInsideWindowWidth(){return window.innerWidth?window.innerWidth:isIE6CSS?document.body.parentElement.clientWidth:document.body&&document.body.clientWidth?document.body.clientWidth:0}
function getInsideWindowHeight(){return window.innerHeight?window.innerHeight:isIE6CSS?document.body.parentElement.clientHeight:document.body&&document.body.clientHeight?document.body.clientHeight:0}function addEvent(a,b,c,d){if(a.addEventListener)return a.addEventListener(b,c,d?!0:!1),!0;if(a.attachEvent)return a.attachEvent("on"+b,c);a["on"+b]=c}var _sCompat_=document.compatMode,bIsCSS1Compat="CSS1Compat"==_sCompat_;
function focus2(){var a,b,c,d;var e=document.getElementsByName("h_fcs");if(0<e.length){e=e[0];for(c=e.parentNode;c;){"TR"==c.tagName&&(a=c);if(a&&"DIV"==c.tagName&&("layer"==c.id&&(b=c),"X1"==c.id||"X2"==c.id)){var f=c;f.HSibling||(f.HSibling=document.getElementById("X1"==c.id?"X2":"X1"));break}c=c.parentNode}var g=(c=b?b.getElementsByTagName("THEAD"):null)&&0<c.length?c[0].offsetHeight+5:0;b?(0<c.length&&"divheader"==c[0].id&&(d=c[0]),d?(e.scrollIntoView(!0),b.scrollTop>=d.offsetHeight&&(b.scrollTop-=
d.offsetHeight)):(b.scrollIntoView(!0),b.scrollTop=Math.max(a.offsetTop-g,0),b.HSibling&&(b.HSibling.scrollTop=Math.max(a.offsetTop-g,0)))):f?(f.scrollIntoView(!0),f.scrollTop=Math.max(a.offsetTop-g,0),f.HSibling&&(f.HSibling.scrollTop=Math.max(a.offsetTop-g,0))):a?window.scrollTo(0,a.offsetTop):e.scrollIntoView(!0)}}
function historyBack(){var a;var b=document.getElementsByTagName("FORM");if(0<b.length)for(b=b[0],a=0;a<b.elements.length;a++){var c=b.elements[a];if(null!=c&&"historyBack"==c.name){"1"==c.value?(c.value="0",b.submit()):c.value="1";break}}}function changeImage(a,b){document.images[a].src=b}var isClicked=!1;function oneClick(){return isClicked?(alert("Don't click twice."),!1):isClicked=!0}
function renew(a,b,c){var d=null;null!=c?d=c.form:(c=document.getElementsByTagName("FORM"),0<c.length&&(d=c[0]));null!=d&&(d.action=a,d.target=b,d.submit())}function nextForm(a,b,c){a.value.length>=c&&(a=a.form.elements[b],null!=a[0]&&null!=a[0].name?a[0].focus():null!=a?a.focus():alert("There is no field named ["+b+"]"))}function checkbox(a){var b;var c=a.form;if(null!=c){c=c.elements;var d=c.length;for(b=0;b<d;b++){var e=c[b];if("h_rowSel"==e.name||"ALL_CHECK"==e.name)e.checked=a.checked}}}
var EMPTY_STR="",strOldKey=EMPTY_STR,oOldSelect=null,BACKSPACE_CODE=8;function clearOldKey(){strOldKey=EMPTY_STR}
function setKeySelect(a){var b;var c=!1;oOldSelect!=a&&(strOldKey=EMPTY_STR,oOldSelect=a,null==a.onblur&&(a.onblur=clearOldKey));var d=a.options;var e=event.keyCode;if(37<=e&&40>=e||48<=e&&90>=e||96<=e&&105>=e||BACKSPACE_CODE==e)if(b=37<=e&&40>=e&&!event.shiftKey)strOldKey=EMPTY_STR;else{b=90>=e?String.fromCharCode(e).toUpperCase():String.fromCharCode(e-48);e=BACKSPACE_CODE==e?0<strOldKey.length?strOldKey.substr(0,strOldKey.length-1):EMPTY_STR:strOldKey+b;var f=e.length;for(b=0;b<d.length;b++)if(e==
d(b).text.substr(0,f).toUpperCase()||e==d(b).value.substr(0,f).toUpperCase()){c=!0;break}c&&(strOldKey=e,a.selectedIndex!=b&&(a.selectedIndex=b));event.returnValue=!1}return c}function window_open(a,b,c,d){null!=b&&(b="left="+b.x+",top="+b.y,null!=d&&(d+=","+b));window.open(a,c,d)}
function adjustFrameHeight(a){var b;if(a){var c=Math.round(1E3/a)/10+"%";$("body").css({zoom:a,width:c,height:c})}else a=1;adjustFrameHeight_iframe();var d=parent.document.getElementsByName("SUB_FRAME");if(null!=d){var e=c=null;1==d.length&&(c=d[0],e=parent.frames);if(null!=c&&null!=c.rows&&0!=c.rows.length&&null!=e&&0!=e.length){var f=c.rows.split(",");d=null;var g=Math.min(f.length,e.length);for(b=0;b<g-1;b++)if(f=e[b].document.getElementById("END_MARKER"),null==f)d=d+e[b].document.body.clientHeight+
",";else{var h=e[b].document.documentElement.scrollWidth;var l=e[b].document.documentElement.clientWidth;var m="a"==/a/[-1];var k=5;if(m||h!=l)k+=14;d=d+Math.ceil((f.offsetTop+f.parentNode.offsetTop)*a)+k+","}c.rows=d+"*"}}}
function adjustFrameWidth(){var a;var b=parent.document.getElementsByName("RES_FRAME");if(null!=b){var c=a=null;1==b.length&&(a=b[0],c=parent.frames);if(null!=a&&null!=a.cols&&0!=a.cols.length&&null!=c&&0!=c.length)for(b=0;b<c.length;b++)if("UPDATE"==c[b].name){sw=c[b].document.documentElement.scrollWidth;c=sw+2;a.cols="*,"+c;break}}}var initRow={};
function autoArea(a,b){var c;if(null!=a&&(null==initRow[a.name]&&(initRow[a.name]=a.rows),isCntAction(event.keyCode))){var d=a.value;var e=1;for(c=d.indexOf("\n");0<=c;)e++,c=d.indexOf("\n",c+1);e<initRow[a.name]&&(e=initRow[a.name]);null!=b&&e>b&&(e=b);a.rows=e}}function isCntAction(a){return 13==a||14==a||8==a||46==a||67==a||86==a||88==a}
function hide(a,b){var c=document.getElementById(a+"A");if(null!=c){var d=document.getElementById(a+"B");a=null;null!=b&&(a=document.getElementsByName(b));if("none"==c.style.display){if(c.style.display="inline",null!=d&&(d.innerHTML="- "),null!=a)for(b=1;b<a.length;b++)a[b].value="false"}else if(c.style.display="none",null!=d&&(d.innerHTML="+ "),null!=a)for(b=1;b<a.length;b++)a[b].value="true"}adjustFrameHeight()}
function replaceText(a,b,c){if(null!=a)for(;0<=a.indexOf(b);)a=a.replace(b,c);return a}function getDimensions(a){var b,c;var d=a.offsetWidth;var e=a.offsetHeight;for(c=b=0;null!=a;a=a.offsetParent)b+=a.offsetTop,c+=a.offsetLeft;return{top:b,left:c,width:d,height:e}}function getClientHeight(){return bIsCSS1Compat?document.documentElement.clientHeight:document.body.clientHeight}function getClientWidth(){return bIsCSS1Compat?document.documentElement.clientWidth:document.body.clientWidth}
function hilightRow(){}function submitPrevNextForm(a){var b=document.forms[0];var c=document.getElementById("h_cmd");null!=b&&null!=c&&(c.value=a,b.submit(),c.value="NEW");return!1}function hideClass(a,b,c,d,e){atsrc=$(b).attr("src");0<=atsrc.indexOf(d)?$(b).attr("src",atsrc.replace(d,e)):$(b).attr("src",atsrc.replace(e,d));$("."+c).toggle();adjustFrameHeight()}var ogEvents={};
function setEvent(a,b,c,d,e,f){null==ogEvents[a]&&(ogEvents[a]=[]);ogEvents[a][ogEvents[a].length]={event:b,"function":c,filter:d,fire:e,bindFunc:f}}var endInitEvent=!1;function bindEvents(a){var b,c,d;for(b in ogEvents){var e=a?a.find(b):$(b);var f=ogEvents[b];for(c=0;c<f.length;c++){f[c].bindFunc&&f[c].bindFunc();var g=f[c].filter?e.filter(f[c].filter):e;g.on(f[c].event,f[c]["function"]);if(f[c].fire)for(d=0;d<g.length;d++)$(g[d]).triggerHandler(f[c].event)}}endInitEvent=!0}
function isEndInitEvent(){return endInitEvent}function selChanged(a){var b=a.textObj;b.value=a.options[a.selectedIndex].value;""==b.value&&(b.value=a.options[a.selectedIndex].text);$(b).trigger("change")}function ogOpen(a,b,c,d){null!=b&&(b="left="+b.x+",top="+b.y,null!=d&&(d+=","+b));window.open(a,c,d)}function setDisplayCapture(a){navigator.clipboard.writeText(a);setTimeout("getDisplayCapture()",1E3)}
function getDisplayCapture(){let a=navigator.clipboard.readText();0==a.lastIndexOf("ERROR:",0)&&alert(a);return a}
function adjustFrameHeight_iframe(){var a=$("iframe.HYBS_IFRAME",parent.document);if(!(1>a.length)){var b=0,c=document.documentElement.scrollWidth,d=document.documentElement.clientWidth,e="a"==/a/[-1];$(a).each(function(f,g){if(f!=a.length-1){f=$("#END_MARKER",$(g).contents())[0];var h=5;if(e||c!=d)h+=14;f=f.offsetTop+f.parentNode.offsetTop+h;$(g).height(f);b=b+f+8}else $(g).css("height","calc(100% - "+b+"px)").css("min-height","100px")})}}
function dateFormat(a,b){b=b.replace(/yyyy/,a.getFullYear());b=b.replace(/MM/,("0"+(a.getMonth()+1)).slice(-2));b=b.replace(/dd/,("0"+a.getDate()).slice(-2));b=b.replace(/HH/,("0"+a.getHours()).slice(-2));b=b.replace(/mm/,("0"+a.getMinutes()).slice(-2));return b=b.replace(/ss/,("0"+a.getSeconds()).slice(-2))}
function toZenkakuKana(a){for(var b="\uff67 \uff68 \uff69 \uff6a \uff6b \uff6c \uff6d \uff6e \uff6f \uff70 \uff73\uff9e \uff76\uff9e \uff77\uff9e \uff78\uff9e \uff79\uff9e \uff7a\uff9e \uff7b\uff9e \uff7c\uff9e \uff7d\uff9e \uff7e\uff9e \uff7f\uff9e \uff80\uff9e \uff81\uff9e \uff82\uff9e \uff83\uff9e \uff84\uff9e \uff8a\uff9e \uff8b\uff9e \uff8c\uff9e \uff8d\uff9e \uff8e\uff9e \uff8a\uff9f \uff8b\uff9f \uff8c\uff9f \uff8d\uff9f \uff8e\uff9f \uff71 \uff72 \uff73 \uff74 \uff75 \uff76 \uff77 \uff78 \uff79 \uff7a \uff7b \uff7c \uff7d \uff7e \uff7f \uff80 \uff81 \uff82 \uff83 \uff84 \uff85 \uff86 \uff87 \uff88 \uff89 \uff8a \uff8b \uff8c \uff8d \uff8e \uff8f \uff90 \uff91 \uff92 \uff93 \uff94 \uff95 \uff96 \uff97 \uff98 \uff99 \uff9a \uff9b \uff9c \uff66 \uff9d".split(" "),c=
"\u30a1\u30a3\u30a5\u30a7\u30a9\u30e3\u30e5\u30e7\u30c3\u30fc\u30f4\u30ac\u30ae\u30b0\u30b2\u30b4\u30b6\u30b8\u30ba\u30bc\u30be\u30c0\u30c2\u30c5\u30c7\u30c9\u30d0\u30d3\u30d6\u30d9\u30dc\u30d1\u30d4\u30d7\u30da\u30dd\u30a2\u30a4\u30a6\u30a8\u30aa\u30ab\u30ad\u30af\u30b1\u30b3\u30b5\u30b7\u30b9\u30bb\u30bd\u30bf\u30c1\u30c4\u30c6\u30c8\u30ca\u30cb\u30cc\u30cd\u30ce\u30cf\u30d2\u30d5\u30d8\u30db\u30de\u30df\u30e0\u30e1\u30e2\u30e4\u30e6\u30e8\u30e9\u30ea\u30eb\u30ec\u30ed\u30ef\u30f2\u30f3".split(""),
d=0;d<b.length;d++)a=a.replace(new RegExp(b[d],"g"),c[d]);return a}var ajaxCall=function(a){$.ajax({url:a,async:!1,type:"GET",dataType:"html"})};
